<?php
/**
 * DBCart 商城系统
 *
 * ==========================================================================
 * @link      https://www.dbcart.cn/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbcart.cn/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace Cms\Service;

use Cms\Entity\CmsClassContent;
use Doctrine\ORM\EntityManager;

class CmsClassContentManager
{
    private $entityManager;

    public function __construct(
        EntityManager $entityManager
    )
    {
        $this->entityManager = $entityManager;
    }

    /**
     * 添加或编辑文章分类内容
     * @param array $data
     * @param $cmsClassId
     * @return void
     * @throws \Doctrine\ORM\ORMException
     * @throws \Doctrine\ORM\OptimisticLockException
     */
    public function addOrEditCmsClassContent(array $data, $cmsClassId)
    {
        foreach (SHOP_LANGUAGE as $language) {
            $classContent   = $this->entityManager->getRepository(CmsClassContent::class)->findOneBy(['cmsClassId' => $cmsClassId, 'languageCode' => $language]);
            $emptyState     = false;
            if ($classContent == null) {
                $classContent = new CmsClassContent();
                $classContent->setLanguageCode($language);
                $classContent->setCmsClassId($cmsClassId);
                $emptyState = true;
            }
            $classContent->setCmsClassName($data['cmsClassName'.$language]);
            $classContent->setCmsClassExtendName($data['cmsClassExtendName'.$language]);
            $classContent->setCmsClassKeywords($data['cmsClassKeywords'.$language]);
            $classContent->setCmsClassDescription($data['cmsClassDescription'.$language]);

            if ($emptyState) $this->entityManager->persist($classContent);

            $this->entityManager->flush();
        }
    }

    /**
     * 删除文章分类内容
     * @param $cmsClassId
     * @return void
     */
    public function deleteCmsClassContent($cmsClassId)
    {
        $qb = $this->entityManager->createQueryBuilder();
        $qb->delete(CmsClassContent::class, 'c')->where($qb->expr()->eq('c.cmsClassId', $cmsClassId));
        $qb->getQuery()->execute();
    }
}