<?php
/**
 * DBCart 商城系统
 *
 * ==========================================================================
 * @link      https://www.dbcart.cn/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbcart.cn/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace Goods\Form;

use Admin\Data\Common;
use Admin\Data\Config;
use Admin\Filter\ImageThumb;
use Admin\Filter\OldImage;
use Admin\Validator\ImageSuffixValidator;
use Laminas\Form\Form;

class GoodsBrandForm extends Form
{
    private $brand;

    public $inputFilter;

    public function __construct($brand = null, $name = 'goods-brand-form', $options = [])
    {
        parent::__construct($name, $options);
        $this->setAttribute('method', 'post');
        $this->setAttribute('enctype', 'multipart/form-data');
        $this->setAttribute('class', 'form-horizontal');

        $this->brand = $brand;

        $this->addElements();
        $this->inputFilter = $this->addInputFilter();
    }

    protected function addElements()
    {
        foreach (SHOP_LANGUAGE as $language) {
            $this->add([
                'type'  => 'text',
                'name'  => 'brandName'.$language,
                'attributes'    => [
                    'id'            => 'brandName'.$language,
                    'class'         => 'form-control'
                ]
            ]);

            $this->add([
                'type'  => 'text',
                'name'  => 'brandInfo'.$language
            ]);

            $this->add([
                'type'  => 'text',
                'name'  => 'brandNameExtend'.$language,
                'attributes'    => [
                    'id'            => 'brandNameExtend'.$language,
                    'class'         => 'form-control'
                ]
            ]);

            $this->add([
                'type'  => 'text',
                'name'  => 'brandKeywords'.$language,
                'attributes'    => [
                    'id'            => 'brandKeywords'.$language,
                    'class'         => 'form-control'
                ]
            ]);

            $this->add([
                'type'  => 'textarea',
                'name'  => 'brandDescription'.$language,
                'attributes'    => [
                    'id'            => 'brandDescription'.$language,
                    'class'         => 'form-control',
                    'rows'          => 4
                ]
            ]);
        }

        $this->add([
            'type'  => 'file',
            'name'  => 'brandLogo',
            'attributes'    => [
                'id'            => 'brandLogo',
                'class'         => 'form-control'
            ]
        ]);

        $this->add([
            'type'  => 'number',
            'name'  => 'brandSort',
            'attributes'    => [
                'id'            => 'brandSort',
                'class'         => 'form-control',
                'value'         => 255
            ]
        ]);

        $this->add([
            'type'  => 'multiCheckbox',
            'name'  => 'inClassId'
        ]);
    }

    protected function addInputFilter()
    {
        $inputFilter = $this->getInputFilter();

        foreach (SHOP_LANGUAGE as $language) {
            $inputFilter->add([
                'name'      => 'brandName'.$language,
                'required'  => true,
                'filters'   => [
                    ['name' => 'StringTrim'],
                    ['name' => 'StripTags']
                ],
                'validators'=> [
                    [
                        'name'      => 'StringLength',
                        'options'   => [
                            'min'   => 1,
                            'max'   => 150
                        ]
                    ]
                ]
            ]);

            $inputFilter->add([
                'name'      => 'brandInfo'.$language,
                'required'  => false,
                'filters'   => [
                    ['name' => 'StringTrim']
                ]
            ]);

            $inputFilter->add([
                'name'      => 'brandNameExtend'.$language,
                'required'  => false,
                'filters'   => [
                    ['name' => 'StringTrim'],
                    ['name' => 'StripTags']
                ],
                'validators'=> [
                    [
                        'name'      => 'StringLength',
                        'options'   => [
                            'min'   => 1,
                            'max'   => 255
                        ]
                    ]
                ]
            ]);

            $inputFilter->add([
                'name'      => 'brandKeywords'.$language,
                'required'  => false,
                'filters'   => [
                    ['name' => 'StringTrim'],
                    ['name' => 'StripTags']
                ],
                'validators'=> [
                    [
                        'name'      => 'StringLength',
                        'options'   => [
                            'min'   => 1,
                            'max'   => 255
                        ]
                    ]
                ]
            ]);

            $inputFilter->add([
                'name'      => 'brandDescription'.$language,
                'required'  => false,
                'filters'   => [
                    ['name' => 'StringTrim'],
                    ['name' => 'StripTags']
                ],
                'validators'=> [
                    [
                        'name'      => 'StringLength',
                        'options'   => [
                            'min'   => 1,
                            'max'   => 1000
                        ]
                    ]
                ]
            ]);
        }

        $inputFilter->add([
            'type'      => 'Laminas\InputFilter\FileInput',
            'name'      => 'brandLogo',
            'required'  => false,
            'validators'=> [
                ['name' => 'FileUploadFile'],
                ['name' => ImageSuffixValidator::class],
                [
                    'name' => 'FileMimeType',
                    'options' => [
                        'mimeType' => Common::configValue('image_type')
                    ]
                ],
                ['name' => 'FileIsImage'],
                [
                    'name' => 'FileSize',
                    'options' => Common::configValue('upload_image_max')
                ]
            ],
            'filters'  => [
                [
                    'name' => 'FileRenameUpload',
                    'options' => [
                        'target' => Config::GOODS_BRAND_IMAGE_PATH,
                        'useUploadName'=>true,
                        'useUploadExtension'=>true,
                        'overwrite'=>true,
                        'randomize' => true
                    ]
                ],
                [
                    'name' => ImageThumb::class,
                    'options' => [
                        'width' => Common::configValue('brand_logo_width'),
                        'height'=> Common::configValue('brand_logo_height'),
                        'mode'  => Common::configValue('brand_logo_crop')
                    ]
                ],
                [
                    'name' => OldImage::class,
                    'options' => [
                        'oldImage' => $this->brand ? $this->brand->getBrandLogo() : ''
                    ]
                ]
            ]
        ]);

        $inputFilter->add([
            'name'      => 'brandSort',
            'required'  => true,
            'filters'   => [
                ['name' => 'ToInt']
            ],
            'validators'=> [
                [
                    'name'      => 'GreaterThan',
                    'options'   => [
                        'min'   => 0
                    ]
                ]
            ]
        ]);

        $inputFilter->add([
            'name'      => 'inClassId',
            'required'  => false,
            'filters'   => [
                ['name' => 'ToInt']
            ]
        ]);

        return $inputFilter;
    }
}