<?php
/**
 * DBCart 商城系统
 *
 * ==========================================================================
 * @link      https://www.dbcart.cn/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbcart.cn/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace Goods\Repository;

use Doctrine\ORM\EntityRepository;
use Goods\Entity\GoodsAttribute;
use Goods\Entity\GoodsAttributeContent;

class GoodsAttributeRepository extends EntityRepository
{
    /**
     * 商品属性信息
     * @param $attributeId
     * @return float|int|mixed|string|null
     * @throws \Doctrine\ORM\NonUniqueResultException
     */
    public function findOneAttribute($attributeId)
    {
        return $this->getEntityManager()->createQueryBuilder()
            ->select('a')
            ->addSelect("(SELECT c.attributeName FROM ".GoodsAttributeContent::class." AS c WHERE c.attributeId = a.attributeId AND c.languageCode='".SHOP_FONT_LANGUAGE."') AS attributeName")
            ->from(GoodsAttribute::class, 'a')
            ->where('a.attributeId = :attributeId')->setParameter('attributeId', $attributeId)
            ->getQuery()->getOneOrNullResult();
    }

    /**
     * 根据属性组查询属性
     * @param $attributeGroupId
     * @return float|int|mixed|string
     */
    public function findAttributeList($attributeGroupId)
    {
        $query = $this->getEntityManager()->createQueryBuilder();
        $query->select('a')
            ->addSelect("(SELECT c.attributeName FROM ".GoodsAttributeContent::class." AS c WHERE c.attributeId = a.attributeId AND c.languageCode='".SHOP_FONT_LANGUAGE."') AS attributeName")
            ->from(GoodsAttribute::class, 'a')
            ->where('a.attributeGroupId = :attributeGroupId')->setParameter('attributeGroupId', $attributeGroupId)
            ->orderBy('a.attributeSort', 'ASC')
            ->addOrderBy('a.attributeId', 'ASC');

        return $query->getQuery()->getResult();
    }

    /**
     * 商品属性列表
     * @return mixed
     */
    public function findAllAttribute()
    {
        return $this->getEntityManager()->createQueryBuilder()
            ->select('a', 'g')
            ->addSelect("(SELECT c.attributeName FROM ".GoodsAttributeContent::class." AS c WHERE c.attributeId = a.attributeId AND c.languageCode='".SHOP_FONT_LANGUAGE."') AS attributeName")
            ->from(GoodsAttribute::class, 'a')
            ->leftJoin('a.oneAttributeGroup', 'g')
            ->orderBy('a.attributeSort', 'ASC')
            ->addOrderBy('a.attributeId', 'ASC')
            ->getQuery()->getResult();
    }

    /*===========================================前台===========================================*/
    /**
     * 根据属性组查询属性
     * @param $attributeGroupId
     * @param $languageCode
     * @return float|int|mixed|string
     */
    public function findShopAttributeList($attributeGroupId, $languageCode)
    {
        $query = $this->getEntityManager()->createQueryBuilder();
        $query->select('a')
            ->addSelect("(SELECT c.attributeName FROM ".GoodsAttributeContent::class." AS c WHERE c.attributeId = a.attributeId AND c.languageCode='".$languageCode."') AS attributeName")
            ->from(GoodsAttribute::class, 'a')
            ->where('a.attributeGroupId = :attributeGroupId')->setParameter('attributeGroupId', $attributeGroupId)
            ->orderBy('a.attributeSort', 'ASC')
            ->addOrderBy('a.attributeId', 'ASC');

        return $query->getQuery()->getResult();
    }

}