<?php
/**
 * DBCart 商城系统
 *
 * ==========================================================================
 * @link      https://www.dbcart.cn/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbcart.cn/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace Goods\Repository;

use Doctrine\ORM\EntityRepository;
use Doctrine\ORM\Query\Expr\Join;
use Goods\Entity\GoodsClass;
use Goods\Entity\GoodsClassContent;
use Goods\Entity\GoodsInClass;
use function Doctrine\ORM\QueryBuilder;

class GoodsClassRepository extends EntityRepository
{
    /**
     * 全部分类(后台)
     * @return float|int|mixed|string
     */
    public function findAllClass()
    {
        $query = $this->getEntityManager()->createQueryBuilder();
        $query->select('c', 'cl.className')
            ->from(GoodsClass::class, 'c')
            ->leftJoin(GoodsClassContent::class, 'cl', Join::WITH, 'c.classId = cl.classId')
            ->where('cl.languageCode = :languageCode')->setParameter('languageCode', SHOP_FONT_LANGUAGE)
            ->orderBy('c.classTopId', 'ASC')->addOrderBy('c.classSort', 'ASC');

        return $query->getQuery()->getResult();
    }

    /**
     * 分类列表（后台）
     * @return int|mixed|string
     */
    public function findClassList()
    {
        $query = $this->getEntityManager()->createQueryBuilder();
        $query->select('c', 'cl.className')
            ->addSelect('(SELECT COUNT(i.inId) FROM '.GoodsInClass::class.' AS i WHERE i.classId = c.classId) AS goodsNum')
            ->from(GoodsClass::class, 'c')
            ->leftJoin(GoodsClassContent::class, 'cl', Join::WITH, 'c.classId = cl.classId')
            ->where('cl.languageCode = :languageCode')->setParameter('languageCode', SHOP_FONT_LANGUAGE)
            ->orderBy('c.classTopId', 'ASC')->addOrderBy('c.classSort', 'ASC');

        return $query->getQuery()->getResult();
    }

    /**
     * 分类下级
     * @param $str
     * @param false $state
     * @return int|mixed|string
     */
    public function findClassSub($str, bool $state = false)
    {
        $query = $this->getEntityManager()->createQueryBuilder()
            ->select('c')
            ->from(GoodsClass::class, 'c')
            ->where('c.classPath LIKE :word')
            ->setParameter('word', $str . '%');

        if ($state) {
            $query->andWhere('c.classState = :state')->setParameter('state', 1);
            $query->orderBy('c.classTopId', 'ASC')->addOrderBy('c.classSort', 'ASC');
        }

        return $query->getQuery()->getResult();
    }

    /*==============================================下面为前台调用==============================================*/
    /**
     * 商品分类面包屑
     * @param GoodsClass $goodsClass
     * @param $languageCode
     * @return float|int|mixed|string
     */
    public function shopClassBreadcrumbs(GoodsClass $goodsClass, $languageCode)
    {
        $query = $this->getEntityManager()->createQueryBuilder();
        $query->select('c')
            ->addSelect("(SELECT cl.className FROM ".GoodsClassContent::class." AS cl WHERE cl.classId=c.classId AND cl.languageCode='".$languageCode."') AS className")
            ->from(GoodsClass::class, 'c')
            ->where($query->expr()->in('c.classId', $goodsClass->getClassPath()))
            ->orderBy('c.classPath', 'ASC');

        return $query->getQuery()->getResult();
    }

    /**
     * 全部分类
     * @return float|int|mixed|string
     */
    public function findShopAllClass($languageCode)
    {
        $query = $this->getEntityManager()->createQueryBuilder();
        $query->select('c', 'cl.className')
            ->from(GoodsClass::class, 'c')
            ->leftJoin(GoodsClassContent::class, 'cl', Join::WITH, 'c.classId = cl.classId')
            ->where('cl.languageCode = :languageCode')->setParameter('languageCode', $languageCode)
            ->andWhere('c.classState = :classState')->setParameter('classState', 1)
            ->orderBy('c.classTopId', 'ASC')->addOrderBy('c.classSort', 'ASC');

        return $query->getQuery()->getResult();
    }

    /**
     * 下级分类
     * @param $classTopId
     * @param $languageCode
     * @return float|int|mixed|string
     */
    public function findShopClassSub($classTopId, $languageCode)
    {
        $query = $this->getEntityManager()->createQueryBuilder();
        $query->select('c', 'cl.className')
            ->from(GoodsClass::class, 'c')
            ->leftJoin(GoodsClassContent::class, 'cl', Join::WITH, 'c.classId = cl.classId')
            ->where('cl.languageCode = :languageCode')->setParameter('languageCode', $languageCode)
            ->andWhere('c.classState = :classState')->setParameter('classState', 1)
            ->andWhere('c.classTopId = :classTopId')->setParameter('classTopId', $classTopId)
            ->orderBy('c.classSort', 'ASC');

        return $query->getQuery()->getResult();
    }
}