<?php
/**
 * DBCart 商城系统
 *
 * ==========================================================================
 * @link      https://www.dbcart.cn/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbcart.cn/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace User\Form;

use Laminas\Form\Form;

class UserGroupForm extends Form
{
    public $inputFilter;

    public function __construct($name = 'user-group-form', $options = [])
    {
        parent::__construct($name, $options);
        $this->setAttribute('method', 'post');
        $this->setAttribute('class', 'form-horizontal');

        $this->addElements();
        $this->inputFilter = $this->addInputFilter();
    }

    protected function addElements()
    {
        foreach (SHOP_LANGUAGE as $language) {
            $this->add([
                'type'  => 'text',
                'name'  => 'userGroupName'.$language,
                'attributes'    => [
                    'id'            => 'userGroupName'.$language,
                    'class'         => 'form-control'
                ]
            ]);
        }

        $this->add([
            'type'  => 'number',
            'name'  => 'integralStart',
            'attributes'    => [
                'id'    => 'integralStart',
                'class' => 'form-control',
                'min'   => 0
            ]
        ]);

        $this->add([
            'type'  => 'number',
            'name'  => 'integralEnd',
            'attributes'    => [
                'id'    => 'integralEnd',
                'class' => 'form-control',
                'min'   => 0
            ]
        ]);

        $this->add([
            'type'  => 'checkbox',
            'name'  => 'integralState',
            'attributes'    => [
                'id'            => 'integralState'
            ]
        ]);
    }

    protected function addInputFilter()
    {
        $inputFilter = $this->getInputFilter();

        foreach (SHOP_LANGUAGE as $language) {
            $inputFilter->add([
                'name'      => 'userGroupName'.$language,
                'required'  => true,
                'filters'   => [
                    ['name' => 'StringTrim'],
                    ['name' => 'StripTags']
                ],
                'validators'=> [
                    [
                        'name'      => 'StringLength',
                        'options'   => [
                            'min'   => 1,
                            'max'   => 150
                        ]
                    ]
                ]
            ]);
        }

        $inputFilter->add([
            'name'      => 'integralStart',
            'required'  => false,
            'filters'   => [
                ['name' => 'ToInt']
            ],
            'validators'=> [
                [
                    'name'      => 'GreaterThan',
                    'options'   => [
                        'min'   => 0,
                        'inclusive' => true
                    ]
                ]
            ]
        ]);

        $inputFilter->add([
            'name'      => 'integralEnd',
            'required'  => false,
            'filters'   => [
                ['name' => 'ToInt']
            ],
            'validators'=> [
                [
                    'name'      => 'GreaterThan',
                    'options'   => [
                        'min'   => 0,
                        'inclusive' => true
                    ]
                ]
            ]
        ]);

        $inputFilter->add([
            'name'      => 'integralState',
            'required'  => false,
            'validators'=> [
                [
                    'name'      => 'InArray',
                    'options'   => [
                        'haystack'  => [0, 1]
                    ]
                ]
            ]
        ]);

        return $inputFilter;
    }
}