<?php
/**
 * DBCart 商城系统
 *
 * ==========================================================================
 * @link      https://www.dbcart.cn/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbcart.cn/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace User\Service;

use Doctrine\ORM\EntityManager;
use User\Entity\IntegralRuleContent;

class IntegralRuleContentManager
{
    private $entityManager;

    public function __construct(
        EntityManager $entityManager
    )
    {
        $this->entityManager = $entityManager;
    }

    /**
     * 添加嚯编辑积分规则内容
     * @param array $data
     * @param $integralRuleId
     * @return void
     * @throws \Doctrine\ORM\ORMException
     * @throws \Doctrine\ORM\OptimisticLockException
     */
    public function addOrEditIntegralRuleContent(array $data, $integralRuleId)
    {
        foreach (SHOP_LANGUAGE as $language) {
            $ruleInfo = $this->entityManager->getRepository(IntegralRuleContent::class)->findOneBy(['integralRuleId' => $integralRuleId, 'languageCode' => $language]);
            if ($ruleInfo) {
                $ruleInfo->setIntegralRuleTitle($data['integralRuleTitle'.$language]);
                $ruleInfo->setIntegralRuleInfo($data['integralRuleInfo'.$language]);
            } else {
                $ruleInfo = new IntegralRuleContent();
                $ruleInfo->setIntegralRuleId($integralRuleId);
                $ruleInfo->setLanguageCode($language);
                $ruleInfo->setIntegralRuleTitle($data['integralRuleTitle'.$language]);
                $ruleInfo->setIntegralRuleInfo($data['integralRuleInfo'.$language]);

                $this->entityManager->persist($ruleInfo);
            }
            $this->entityManager->flush();
        }
    }

    /**
     * 删除积分规则内容
     * @param $integralRuleId
     * @return void
     */
    public function deleteIntegralRuleContent($integralRuleId)
    {
        $qb = $this->entityManager->createQueryBuilder();
        $qb->delete(IntegralRuleContent::class, 'i')->where($qb->expr()->eq('i.integralRuleId', $integralRuleId));
        $qb->getQuery()->execute();
    }
}